==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/switchtobuddy/kdevswitchtobuddy.desktop.cmake <==
[Desktop Entry]
Type=Service
Comment=Allows switching between buddy documents like implementation and header file.
Comment[bs]=Dopušta prebacivanje između prijatelj-dokumenata, poput datoteke zaglavlja i implementacije
Comment[ca]=Permet commutar entre document associats com fitxers d'implementacions i de capçaleres.
Comment[ca@valencia]=Permet commutar entre document associats com fitxers d'implementacions i de capçaleres.
Comment[da]=Gør det muligt at skifte imellem vennedokumenter som implementerings- og headerfil.
Comment[de]=Ermöglicht das Umschalten zwischen verwandten Dokumenten wie Implementations- und Header-Dateien.
Comment[el]=Επιτρέπει την εναλλαγή ανάμεσα σε συμπληρωματικά έγγραφα όπως αρχεία implementation και header
Comment[es]=Permite cambiar entre documentos relacionados, como la implementación y el archivo de cabecera.
Comment[et]=Võimaldab lülituda sõltlasdokumentide, näiteks teostus- ja päisefaili vahel.
Comment[fi]=Mahdollistaa vaihtamisen yhteen kuuluvien tiedostojen, kuten toteutus- ja otsikkotiedoston, välillä.
Comment[fr]=Permet de basculer entre des documents similaires comme le fichier d'implémentation et d'en-tête.
Comment[gl]=Permite trocar entre documentos tipo buddy como implementación e ficheiro de cabeceira.
Comment[hu]=Lehetővé teszi az ismerős dokumentum mint megvalósítás és a fejlécfájl közötti váltást.
Comment[it]=Consente il passaggio tra i documenti associati come implementazioni e header file.
Comment[kk]=Іске асыруы не айдары секілді тиісті құжат файлдарына ауысу мүмкіндігі.
Comment[nb]=Tillater å bytte mellom kameratdokumenter slik som implementeringsfila og hodefila.
Comment[nl]=Biedt omschakelen tussen buddy-documenten zoals implementatie en header-bestand.
Comment[pl]=Pozwala na przełączanie pomiędzy stowarzyszonymi dokumentami takimi jak pliki implementacji i nagłówków.
Comment[pt]=Permite a mudança de documentos associados, como os ficheiros de implementação e de inclusão.
Comment[pt_BR]=Permite a mudança de documentos associados, como os arquivos de implementação e de inclusão.
Comment[ru]=Позволяет переключаться между связанными документами, например файлом реализации и заголовочным файлом.
Comment[sk]=Umožňuje prepínanie medzi dokumentmi priateľov ako súbor implementácie a hlavičky.
Comment[sl]=Omogoča preklapljanje med prijateljskimi dokumenti kot na primer izvedbo in datoteko glave.
Comment[sv]=Tillåter byte mellan samhörande dokument som implementerings- och deklarationsfiler.
Comment[tr]=Gerçekleme ve başlık dosyası benzeri dost belgeler arasında geçişi sağlar.
Comment[uk]=Надає змогу перемикатися на споріднені документи, зокрема файли з реалізацією та файли заголовків.
Comment[x-test]=xxAllows switching between buddy documents like implementation and header file.xx
Comment[zh_CN]=允许在伙伴文件中切换，如实现与头文件
Comment[zh_TW]=允許在相關文件，如實作與標頭檔間切換。
Name=Switch to Buddy
Name[bs]=Pređi na prijatelja
Name[ca]=Commuta a associat
Name[ca@valencia]=Commuta a associat
Name[da]=Skift til vennefil
Name[de]=Zu verwandtem Element wechseln
Name[el]=Εναλλαγή στο συμπληρωματικό
Name[es]=Cambiar a relacionado
Name[et]=Lülitumine sõltlasele
Name[fi]=Vaihda yhteen kuuluvaan tiedostoon
Name[fr]=Passage à Buddy
Name[gl]=Pasar a Buddy
Name[hu]=Váltás az ismerősre
Name[it]=Passa al file associato
Name[kk]=Тиістіге ауысу
Name[nb]=Bytt til kamerat
Name[nl]=Naar Buddy omschakelen
Name[pl]=Przełącz do stowarzyszonego
Name[pt]=Mudar para o Ficheiro Associado
Name[pt_BR]=Mudar para o arquivo associado
Name[ru]=Переход к связанному
Name[sk]=Prepnúť na Buddy
Name[sl]=Preklopi na prijatelja
Name[sv]=Byt till samhörande
Name[tr]=Dosta Geçiş Yap
Name[uk]=Перемикання на споріднений
Name[x-test]=xxSwitch to Buddyxx
Name[zh_CN]=切换至伙伴文件
Name[zh_TW]=切換到相關文件
GenericName=Switch to Buddy
GenericName[bs]=Pređi na prijatelja
GenericName[ca]=Commuta a associat
GenericName[ca@valencia]=Commuta a associat
GenericName[da]=Skift til vennefil
GenericName[de]=Zu verwandtem Element wechseln
GenericName[el]=Εναλλαγή στο συμπληρωματικό
GenericName[es]=Cambiar a relacionado
GenericName[et]=Lülitumine sõltlasele
GenericName[fi]=Vaihda yhteen kuuluvaan tiedostoon
GenericName[fr]=Passer à Buddy
GenericName[gl]=Pasar a Buddy
GenericName[hu]=Váltás az ismerősre
GenericName[it]=Passa al file associato
GenericName[kk]=Тиістіге ауысу
GenericName[nb]=Bytt til kamerat
GenericName[nl]=Naar Buddy omschakelen
GenericName[pl]=Przełącz do stowarzyszonego
GenericName[pt]=Mudar para o Ficheiro Associado
GenericName[pt_BR]=Mudar para o arquivo associado
GenericName[ru]=Переход к связанному
GenericName[sk]=Prepnúť na Buddy
GenericName[sl]=Preklopi na prijatelja
GenericName[sv]=Byt till samhörande
GenericName[tr]=Dosta Geçiş Yap
GenericName[uk]=Перемикання на споріднений
GenericName[x-test]=xxSwitch to Buddyxx
GenericName[zh_CN]=切换至伙伴文件
GenericName[zh_TW]=切換到相關文件
Icon=document-multiple
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevswitchtobuddy
X-KDE-PluginInfo-Name=kdevswitchtobuddy
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform-1.7.0.tar.xz: kdevplatform-1.7.0/plugins/switchtobuddy/kdevswitchtobuddy.desktop.cmake <==
[Desktop Entry]
Type=Service
Comment=Allows switching between buddy documents like implementation and header file.
Comment[bs]=Dopušta prebacivanje između prijatelj-dokumenata, poput datoteke zaglavlja i implementacije
Comment[ca]=Permet commutar entre document associats com fitxers d'implementacions i de capçaleres.
Comment[ca@valencia]=Permet commutar entre document associats com fitxers d'implementacions i de capçaleres.
Comment[da]=Muliggør skift mellem buddy-dokumenter såsom implementations- og headerfil.
Comment[de]=Ermöglicht das Umschalten zwischen verwandten Dokumenten wie Implementations- und Header-Dateien.
Comment[el]=Επιτρέπει εναλλαγή μεταξύ συμπληρωματικών εγγράφων όπως implementation και header αρχείου.
Comment[en_GB]=Allows switching between buddy documents like implementation and header file.
Comment[es]=Permite cambiar entre documentos relacionados, como la implementación y el archivo de cabecera.
Comment[et]=Võimaldab lülituda sõltlasdokumentide, näiteks teostus- ja päisefaili vahel.
Comment[fi]=Mahdollistaa vaihtamisen yhteen kuuluvien tiedostojen, kuten toteutus- ja otsikkotiedoston, välillä.
Comment[fr]=Permet de basculer entre des documents similaires comme le fichier d'implémentation et d'en-tête.
Comment[gl]=Permite trocar entre documentos tipo buddy como implementación e ficheiro de cabeceira.
Comment[hu]=Lehetővé teszi az ismerős dokumentum mint megvalósítás és a fejlécfájl közötti váltást.
Comment[it]=Consente il passaggio tra i documenti associati come implementazioni e header file.
Comment[kk]=Іске асыруы не айдары секілді тиісті құжат файлдарына ауысу мүмкіндігі.
Comment[nb]=Tillater å bytte mellom kameratdokumenter slik som implementeringsfila og hodefila.
Comment[nl]=Biedt omschakelen tussen buddy-documenten zoals implementatie en header-bestand.
Comment[pl]=Pozwala na przełączanie pomiędzy stowarzyszonymi dokumentami takimi jak pliki implementacji i nagłówków.
Comment[pt]=Permite a mudança de documentos associados, como os ficheiros de implementação e de inclusão.
Comment[pt_BR]=Permite a mudança de documentos associados, como os arquivos de implementação e de inclusão.
Comment[ru]=Позволяет переключаться между связанными документами, например файлом реализации и заголовочным файлом.
Comment[sk]=Umožňuje prepínanie medzi dokumentmi priateľov ako súbor implementácie a hlavičky.
Comment[sl]=Omogoča preklapljanje med prijateljskimi dokumenti kot na primer izvedbo in datoteko glave.
Comment[sv]=Tillåter byte mellan samhörande dokument som implementerings- och deklarationsfiler.
Comment[tr]=Gerçekleme ve başlık dosyası benzeri dost belgeler arasında geçişi sağlar.
Comment[uk]=Надає змогу перемикатися на споріднені документи, зокрема файли з реалізацією та файли заголовків.
Comment[x-test]=xxAllows switching between buddy documents like implementation and header file.xx
Comment[zh_CN]=允许在伙伴文件中切换，如实现与头文件
Comment[zh_TW]=允許在相關文件，如實作與標頭檔間切換。
Name=Switch to Buddy
Name[bs]=Pređi na prijatelja
Name[ca]=Commuta a associat
Name[ca@valencia]=Commuta a associat
Name[da]=Skift til buddy
Name[de]=Zu verwandtem Element wechseln
Name[el]=Εναλλαγή στο συμπληρωματικό
Name[en_GB]=Switch to Buddy
Name[es]=Cambiar a relacionado
Name[et]=Lülitumine sõltlasele
Name[fi]=Vaihda yhteen kuuluvaan tiedostoon
Name[fr]=Passage à Buddy
Name[gl]=Pasar a Buddy
Name[hu]=Váltás az ismerősre
Name[it]=Passa al file associato
Name[kk]=Тиістіге ауысу
Name[nb]=Bytt til kamerat
Name[nl]=Naar Buddy omschakelen
Name[pl]=Przełącz do stowarzyszonego
Name[pt]=Mudar para o Ficheiro Associado
Name[pt_BR]=Mudar para o arquivo associado
Name[ru]=Переход к связанному
Name[sk]=Prepnúť na Buddy
Name[sl]=Preklopi na prijatelja
Name[sv]=Byt till samhörande
Name[tr]=Dosta Geçiş Yap
Name[uk]=Перемикання на споріднений
Name[x-test]=xxSwitch to Buddyxx
Name[zh_CN]=切换至伙伴文件
Name[zh_TW]=切換到相關文件
GenericName=Switch to Buddy
GenericName[bs]=Pređi na prijatelja
GenericName[ca]=Commuta a associat
GenericName[ca@valencia]=Commuta a associat
GenericName[da]=Skift til buddy
GenericName[de]=Zu verwandtem Element wechseln
GenericName[el]=Εναλλαγή στο συμπληρωματικό
GenericName[en_GB]=Switch to Buddy
GenericName[es]=Cambiar a relacionado
GenericName[et]=Lülitumine sõltlasele
GenericName[fi]=Vaihda yhteen kuuluvaan tiedostoon
GenericName[fr]=Passer à Buddy
GenericName[gl]=Pasar a Buddy
GenericName[hu]=Váltás az ismerősre
GenericName[it]=Passa al file associato
GenericName[kk]=Тиістіге ауысу
GenericName[nb]=Bytt til kamerat
GenericName[nl]=Naar Buddy omschakelen
GenericName[pl]=Przełącz do stowarzyszonego
GenericName[pt]=Mudar para o Ficheiro Associado
GenericName[pt_BR]=Mudar para o arquivo associado
GenericName[ru]=Переход к связанному
GenericName[sk]=Prepnúť na Buddy
GenericName[sl]=Preklopi na prijatelja
GenericName[sv]=Byt till samhörande
GenericName[tr]=Dosta Geçiş Yap
GenericName[uk]=Перемикання на споріднений
GenericName[x-test]=xxSwitch to Buddyxx
GenericName[zh_CN]=切换至伙伴文件
GenericName[zh_TW]=切換到相關文件
Icon=document-multiple
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevswitchtobuddy
X-KDE-PluginInfo-Name=kdevswitchtobuddy
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
